{ config, nix-colors, pkgs, lib, ... }:
let
  inherit
  (nix-colors.lib-contrib { inherit pkgs; })
  gtkThemeFromScheme;
in
{
  options = {
    guiTheming.enable = lib.mkEnableOption "Enable GTK and QT theming";
  };

  imports = [
    nix-colors.homeManagerModules.default
  ];

  config = {
    guiTheming.enable = lib.mkDefault true;

    colorScheme = nix-colors.colorSchemes.da-one-sea;

    gtk = lib.mkIf config.guiTheming.enable {
      enable = true;
      theme = {
        name = "${config.colorScheme.slug}";
        package = gtkThemeFromScheme { scheme = config.colorScheme; };
      };
      iconTheme = {
        package = pkgs.qogir-icon-theme;
        name = "Qogir-dark";
      };
    };

    qt = lib.mkIf config.guiTheming.enable {
      enable = true;
      platformTheme.name = "gtk";
      style = {
        name = "gtk2";
        package = pkgs.qt6Packages.qt6gtk2;
      };
    };

    home.pointerCursor = lib.mkIf config.guiTheming.enable {
      package = pkgs.phinger-cursors;
      name = "phinger-cursors-dark";
      size = 24;
      gtk.enable = true;
    };
  };
}
